let
  nixpkgs = <nixpkgs>;
  pkgs = import nixpkgs { };
  internal = import ./internal.nix nixpkgs;
  fixtures = {
    testDrv = import ./fixtures/test-drv.nix;
    testDrvDarwin = import ./fixtures/test-drv-darwin.nix;
  };
in pkgs.lib.runTests {
  # CollectPlatforms
  ##################
  testCollectPlatformsAllDrv = {
    expr = internal.collectPlatformsForDrv fixtures.testDrv ;
    expected = [ "i686-cygwin" "x86_64-cygwin" "x86_64-darwin" "i686-darwin" "aarch64-darwin" "armv7a-darwin" "i686-freebsd13" "x86_64-freebsd13" "aarch64-genode" "i686-genode" "x86_64-genode" "x86_64-solaris" "javascript-ghcjs" "aarch64-linux" "armv5tel-linux" "armv6l-linux" "armv7a-linux" "armv7l-linux" "i686-linux" "m68k-linux" "microblaze-linux" "microblazeel-linux" "mipsel-linux" "mips64el-linux" "powerpc64-linux" "powerpc64le-linux" "riscv32-linux" "riscv64-linux" "s390-linux" "s390x-linux" "x86_64-linux" "mmix-mmixware" "aarch64-netbsd" "armv6l-netbsd" "armv7a-netbsd" "armv7l-netbsd" "i686-netbsd" "m68k-netbsd" "mipsel-netbsd" "powerpc-netbsd" "riscv32-netbsd" "riscv64-netbsd" "x86_64-netbsd" "aarch64_be-none" "aarch64-none" "arm-none" "armv6l-none" "avr-none" "i686-none" "microblaze-none" "microblazeel-none" "msp430-none" "or1k-none" "m68k-none" "powerpc-none" "powerpcle-none" "riscv32-none" "riscv64-none" "rx-none" "s390-none" "s390x-none" "vc4-none" "x86_64-none" "i686-openbsd" "x86_64-openbsd" "x86_64-redox" "wasm64-wasi" "wasm32-wasi" "x86_64-windows" "i686-windows" ];
  };
  testCollectPlatformsDarwinDrv = {
    expr = internal.collectPlatformsForDrv fixtures.testDrvDarwin ;
    expected = [ "x86_64-darwin" "i686-darwin" "aarch64-darwin" "armv7a-darwin" ];
  };

  # genFlakeOutputForPlatforms
  ############################
  testGenFlakeOutputForPlatforms = {
    expr = internal.genFlakeOutputForPlatforms { path = /tmp/dummy/path; name = "hello"; platforms = [ "x86_64-linux" "x86_64-darwin" "aarch64-linux"]; };
    expected = { aarch64-linux = { hello = /tmp/dummy/path; }; x86_64-darwin = { hello = /tmp/dummy/path; }; x86_64-linux = { hello = /tmp/dummy/path; };};
  };
}
